@@ -1,6 +1,6 @@
-var _ = require("./lodash"),
-    grammar = require("./dot-grammar"),
-    buildGraph = require("./build-graph");
+var _ = require("./lodash");
+var grammar = require("./dot-grammar");
+var buildGraph = require("./build-graph");
 
 module.exports = function readMany(str) {
   var parseTree = grammar.parse(str);
